import { UserContent } from 'ai';
import { ZodSchema } from 'zod';
import { Integration } from '../integration';
import { LLM } from '../llm';
import { ModelConfig, StructuredOutput } from '../llm/types';
import { Logger } from '../logger';
import { Run } from '../run/types';
import { Telemetry } from '../telemetry';
import { AllTools, ToolApi } from '../tools/types';
export declare class Agent<TTools, TIntegrations extends Integration[] | undefined = undefined, TKeys extends keyof AllTools<TTools, TIntegrations> = keyof AllTools<TTools, TIntegrations>> {
    #private;
    name: string;
    readonly llm: LLM<TTools, TIntegrations, TKeys>;
    readonly instructions: string;
    readonly model: ModelConfig;
    readonly enabledTools: Partial<Record<TKeys, boolean>>;
    constructor(config: {
        name: string;
        instructions: string;
        model: ModelConfig;
        enabledTools?: Partial<Record<TKeys, boolean>>;
    });
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    /**
     * Set the logger for the agent
     * @param logger
     */
    __setLogger(logger: Logger): void;
    /**
     * Set the telemetry for the agent
     * @param telemetry
     */
    __setTelemetry(telemetry: Telemetry): void;
    text({ messages, onStepFinish, maxSteps, runId, }: {
        messages: UserContent[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateTextResult<{}, never>>;
    textObject({ messages, structuredOutput, onStepFinish, maxSteps, runId, }: {
        messages: UserContent[];
        structuredOutput: StructuredOutput | ZodSchema;
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateObjectResult<any>>;
    stream({ messages, onStepFinish, onFinish, maxSteps, runId, }: {
        messages: UserContent[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamTextResult<{}>>;
    streamObject({ messages, structuredOutput, onStepFinish, onFinish, maxSteps, runId, }: {
        messages: UserContent[];
        structuredOutput: StructuredOutput | ZodSchema;
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamObjectResult<any, any, never>>;
}
