import { CoreMessage, CoreTool as CT, LanguageModelV1 } from 'ai';
import { ZodSchema } from 'zod';
import { Integration } from '../integration';
import { Logger } from '../logger';
import { Run } from '../run/types';
import { Telemetry } from '../telemetry';
import { AllTools, CoreTool, ToolApi } from '../tools/types';
import { CustomModelConfig, EmbeddingModelConfig, GoogleGenerativeAISettings, ModelConfig, StructuredOutput } from './types';
export declare class LLM<TTools, TIntegrations extends Integration[] | undefined = undefined, TKeys extends keyof AllTools<TTools, TIntegrations> = keyof AllTools<TTools, TIntegrations>> {
    #private;
    constructor();
    /**
     * Set the concrete tools for the agent
     * @param tools
     */
    __setTools(tools: Record<TKeys, ToolApi>): void;
    /**
     * Set the logger for the agent
     * @param logger
     */
    __setLogger(logger: Logger): void;
    /**
     * Set the telemetry for the agent
     * @param telemetry
     */
    __setTelemetry(telemetry: Telemetry): void;
    get experimental_telemetry(): {
        tracer: import("@opentelemetry/api").Tracer;
        isEnabled: boolean;
    } | undefined;
    getModelType(model: ModelConfig): string;
    createOpenAICompatibleModel({ baseURL, apiKey, defaultModelName, modelName, fetch, }: {
        baseURL: string;
        apiKey: string;
        defaultModelName: string;
        modelName?: string;
        fetch?: typeof globalThis.fetch;
    }): LanguageModelV1;
    createModelDef({ model, }: {
        model: {
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            fetch?: typeof globalThis.fetch;
            apiKey?: string;
        };
    }): LanguageModelV1;
    createEmbedding({ model, value, maxRetries, }: {
        model: EmbeddingModelConfig;
        value: string[] | string;
        maxRetries: number;
    }): Promise<import("ai").EmbedManyResult<string> | import("ai").EmbedResult<string>>;
    getParams({ tools, resultTool, model, }: {
        tools: Record<string, CoreTool>;
        resultTool?: {
            description: string;
            parameters: ZodSchema;
        };
        model: ({
            type: string;
            name?: string;
            toolChoice?: 'auto' | 'required';
            baseURL?: string;
            apiKey?: string;
            fetch?: typeof globalThis.fetch;
        } & GoogleGenerativeAISettings) | CustomModelConfig;
    }): Promise<{
        toolsConverted: Record<string, CT>;
        modelDef: LanguageModelV1;
        answerTool: {};
        toolChoice: "auto" | "required";
    }>;
    convertTools(enabledTools?: Partial<Record<TKeys, boolean>>): Record<TKeys, CoreTool>;
    private isBaseOutputType;
    private baseOutputTypeSchema;
    private createOutputSchema;
    text({ model, messages, onStepFinish, maxSteps, enabledTools, runId, }: {
        enabledTools?: Partial<Record<TKeys, boolean>>;
        model: ModelConfig;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateTextResult<{}, never>>;
    textObject({ model, messages, onStepFinish, maxSteps, enabledTools, structuredOutput, runId, }: {
        structuredOutput: StructuredOutput | ZodSchema;
        enabledTools?: Partial<Record<TKeys, boolean>>;
        model: ModelConfig;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        maxSteps?: number;
    } & Run): Promise<import("ai").GenerateObjectResult<any>>;
    stream({ model, messages, onStepFinish, onFinish, maxSteps, enabledTools, runId, }: {
        model: ModelConfig;
        enabledTools?: Partial<Record<TKeys, boolean>>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamTextResult<{}>>;
    streamObject({ model, messages, onStepFinish, onFinish, maxSteps, enabledTools, structuredOutput, runId, }: {
        structuredOutput: StructuredOutput | ZodSchema;
        model: ModelConfig;
        enabledTools: Partial<Record<TKeys, boolean>>;
        messages: CoreMessage[];
        onStepFinish?: (step: string) => void;
        onFinish?: (result: string) => Promise<void> | void;
        maxSteps?: number;
    } & Run): Promise<import("ai").StreamObjectResult<any, any, never>>;
}
